function PopupLayout()
{
}

/**
 * the ID of the page body element that is automatically looked for when
 * PopupLayout.initialize() is called.
 */
PopupLayout.PAGE_BODY_CONTAINER_ID = "pageBodyContainer";
PopupLayout.PAGE_BODY_ID = "pageBody";
PopupLayout.BUTTON_BAR_CONTAINER_ID = "popupButtonBarContainer";
PopupLayout.BUTTON_BAR_ID = "popupButtonBar";
PopupLayout.WINDOW_DIMENSIONS = {};

/** the single page body container if there is only one */
PopupLayout.pageBodyContainer = null;

/** the single page body if there is only one */
PopupLayout.pageBody = null;

/** the single poup buttons container if there is only one */
PopupLayout.popupButtonBarContainer = null;

/** the single popup button if there is only one */
PopupLayout.popupButtonBar = null;

/**
 * This function will look for an element called "pageBody" and if it exists
 * then this element will automatically be resized when the size of the browser
 * window changes.
 */
PopupLayout.initialize = function()
{
   PopupLayout.pageBodyContainer = document.getElementById(PopupLayout.PAGE_BODY_CONTAINER_ID);

   PopupLayout.popupButtonBarContainer = document.getElementById(PopupLayout.BUTTON_BAR_CONTAINER_ID);

   if (PopupLayout.popupButtonBarContainer)
   {
      if (PopupLayout.RTL)
      {
         PopupLayout.popupButtonBarContainer.style.right = "0";
      }
      else
      {
         PopupLayout.popupButtonBarContainer.style.left = "0";
      }
      
      PopupLayout.popupButtonBar = document.getElementById(PopupLayout.BUTTON_BAR_ID);
   }

   if (PopupLayout.pageBodyContainer)
   {
      PopupLayout.pageBody = document.getElementById(PopupLayout.PAGE_BODY_ID);
      PopupLayout.pageBodyContainer.style.overflow = "auto";
   }

   Event.observe(window, "resize", PopupLayout.handleWindowOnResize);
   PopupLayout.handleWindowOnResize();
}

/**
 * The default handler for the window.onresize event. This handler will
 * automatically fix the height of the page content area.
 */
PopupLayout.handleWindowOnResize = function(force)
{

   var prevWidth = PopupLayout.WINDOW_DIMENSIONS.width;
   var prevHeight = PopupLayout.WINDOW_DIMENSIONS.height;
   
   PopupLayout.updateWindowDimensions();
   var size = PopupLayout.WINDOW_DIMENSIONS;
   if (!force && (prevWidth===size.width && prevHeight===size.height))
   {
      return;
   }
   
   var newHeight = size.height - PopupLayout.pageBodyContainer.offsetTop;
   var newWidth = size.width;

   if (PopupLayout.popupButtonBarContainer)
   {
      var popupButtonBarHeight = PopupLayout.popupButtonBarContainer.offsetHeight;
      newHeight -= popupButtonBarHeight;
      PopupLayout.popupButtonBarContainer.style.top = size.height
            - popupButtonBarHeight;
      PopupLayout.popupButtonBarContainer.style.width = newWidth + "px";
   }

   if (newHeight > 0)
   {
      PopupLayout.pageBodyContainer.style.height = newHeight + "px";
   }

   if (PopupLayout.pageBody)
   {
      PopupLayout.pageBodyContainer.style.width = newWidth + "px";
      PopupLayout.pageBody.style.width = (newWidth - 30) + "px";
   }
}

PopupLayout.updateWindowDimensions = function()
{
   var width, height = 0;
   cpb.consoleLog("window == " + window);
   cpb.consoleLog("window.innerWidth == " + window.innerWidth);
   if (window.innerWidth !== undefined)
   {
      // Non-IE
      width = window.innerWidth;
      height = window.innerHeight;
   }
   else if (document.documentElement)
   {
      // IE 6+ in 'standards compliant mode'
      width = document.documentElement.clientWidth;
      if (width == 0)
         width = document.body.clientWidth;
      
      height = document.documentElement.clientHeight;
      if (height == 0)
         height = document.body.clientHeight;
   }
   else
   {
      // IE 4 compatible
      width = document.body.clientWidth;
      height = document.body.clientHeight;
   }

   PopupLayout.WINDOW_DIMENSIONS.width = width;
   PopupLayout.WINDOW_DIMENSIONS.height = height;
}

window.PageLayout = PopupLayout;