/*******************************************************************************
  Copyright (c) 2015, SAS Institute Inc., Cary, NC, USA

  All rights reserved. Produced in the United States of America.

  U.S. Government Restricted Rights Notice: Use, duplication, or
  disclosure of this software and related documentation by the U.S.
  government is subject to the Agreement with SAS Institute and the
  restrictions set forth in FAR 52.227-19, Commercial Computer
  Software - Restricted Rights (June 1987).
  SAS Institute Inc., SAS Campus Drive, Cary, North Carolina 27513.

  SAS(R) and all other SAS Institute Inc. product or service
  names are registered trademarks or trademarks of SAS Institute Inc.
  in the USA and other countries. (R) indicates USA
  registration. Other brand and product names are trademarks of their
  respective companies.
*******************************************************************************/

%macro ecm_loadrr_ref_country_state_cd;

/*******************************************************************************/
/*  LOAD ISO standard country codes                                            */
/*******************************************************************************/
 
data ref_table_value_country;

     if 0 then set ecm_db.Ref_table_value; 
     infile  "&form_path&slash.country_names_and_code_elements.txt"  
             dsd lrecl=32764 truncover firstobs=2 delimiter=';' ;
     
     retain ref_table_nm 'X_RT_COUNTRY';
     retain value_cd value_desc display_order_no; 
     keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no active_flg;
   
     input value_desc $
           value_cd
     ; 
     value_desc=tranwrd(tranwrd(tranwrd(propcase(value_desc),' Of',' of'),' And ',' and '),'The ','the ');

     display_order_no+1;
	 active_flg='1';
     if value_cd ne '' then output;
     
run;
/* Set US as the first choice in the list */
proc sql noprint;
     update ref_table_value_country
     set display_order_no=0
     where ref_table_nm='X_RT_COUNTRY' and value_cd='US'
     ;
    
quit;

/*******************************************************************************/
/*  LOAD US/CA/MX state codes                                                  */
/*******************************************************************************/
 
data ref_table_value_state;

     if 0 then set ecm_db.Ref_table_value; 
     infile  "&form_path&slash.state_code_list.csv"  
             dsd lrecl=32764 truncover delimiter=',' ;
     
     retain ref_table_nm 'X_RT_STATE_PROVINCE'
            parent_ref_table_nm 'X_RT_COUNTRY'
     ;
     retain value_cd value_desc display_order_no; 
     keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no active_flg;
   
     input parent_value_cd $
           value_cd $ 
           value_desc $
     ;
	 active_flg='1';
     if lag(parent_value_cd) ne parent_value_cd then display_order_no=1;
     else display_order_no+1;
         
run;

%if &sysrc <= 4 %then
%do;
    proc sql noprint;
         delete from ecm_db.ref_table_value
         where ref_table_nm='X_RT_STATE_PROVINCE'
    ;
         delete from ecm_db.ref_table_value
         where ref_table_nm='X_RT_COUNTRY'
    ;
    quit;

    proc append base=ecm_db.ref_table_value data=ref_table_value_country force;
    run;
    
    proc append base=ecm_db.ref_table_value data=ref_table_value_state force;
    run;
%end;

%mend;
 
%let form_path=&ecm_config_path&slash.Source&slash.form_template;
%ecm_loadrr_ref_country_state_cd;   /* load country and state/province codes  */
