/***********************************************************************************/
/* Copyright (c) 2011, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecm_pivot_extract_udf_by_type                                    */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Extract the UDF data from UDF tables                             */
/* PARAMETERS:                                                                     */
/*                datatype: type of data to subset (case,party,incident,           */
/*                          generic_data) and transpose                            */
/*                in_lib: libname of the source data                               */
/*                out_lib: libname of the target data                              */
/*                udf_table_nm: name of udf table                                  */
/*                udf_type: char, num, date, lgchr                                 */
/*                out_dsn: output table name                                       */
/*                datatype_rk: list of rk of the datatype (for small amount)       */
/*                subset_dsn: table containing a list of datatype_rk for subsetting*/
/*                            (for longer list)                                    */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecm_pivot_extract_udf_by_type(in_lib=ecm_db
                                     , datatype= 
                                     , out_lib=work
                                     , udf_type=
                                     , udf_table_nm=
                                     , out_dsn=
                                     , datatype_rk=
                                     , subset_dsn=);
                                       
   %put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;



%if &udf_type ne LGCHR %then
%do;
proc sql;
   create table &out_dsn as 
   select a.&datatype._rk, a.valid_from_dttm, a.udf_table_nm, a.udf_nm,  a.udf_value as UDF_VALUE_&udf_type
  
   %if &datatype=GENERIC_DATA %then
   %do;  
        ,1 as row_no
   %end; 
   %else
   %do;
        ,a.row_no
   %end;
   from &in_lib..&datatype._udf_&udf_type._value as a
   
  /* GENERIC DATA does not have LIVE table */
   %if &datatype ne GENERIC_DATA %then
   %do;
   , &in_lib..&datatype._live as b 
   where upcase(a.udf_table_nm)="&udf_table_nm" and a.&datatype._rk=b.&datatype._rk and a.valid_from_dttm=b.valid_from_dttm
   %end; 
   %else
   %do;
   where   upcase(a.udf_table_nm)="&udf_table_nm" and a.valid_to_dttm=.
   %end;
   /* filter the data if datatype_rk or subset_dsn is non blank */
   %if &datatype_rk ne %then
   %do;
        and a.&datatype._rk in (&datatype_rk) 
    %end;
    %else %if &subset_dsn ne %then
    %do;
        and a.&datatype._rk in (select distinct &datatype._rk from &subset_dsn)
    %end;
   
; quit;
proc sort data=&out_dsn;
by &datatype._rk row_no udf_nm;;
run;

%end;
%else
%do;
  /* For LGCHR, transpose the udf_lgchr_view from two columns (udf_value_1 and udf_value_2)  */
  /* into two records: udf_nm and udf_nm||'_2'                                               */
 
  proc sql;
   %local j;
       create table &out_dsn as

  %do j=1 %to 2; 
     %if &j ne 1 %then 
       %do; 
            union
     %end;
     (select a.&datatype._rk
            , a.valid_from_dttm
            , a.udf_table_nm
            , strip(a.udf_nm)
            %if &j > 1 %then
            %do;
              ||"_&j" 
            %end; 
              as udf_nm length=120
            ,  a.udf_value_&j as udf_value_lgchr
    
     %if &datatype=GENERIC_DATA %then
     %do;  
          ,1 as row_no
     %end; 
     %else
     %do;
          ,a.row_no
     %end;
     from &in_lib..&datatype._udf_lgchr_view as a
     %if &datatype ne GENERIC_DATA %then
     %do;
         , &in_lib..&datatype._live as b 
         where upcase(a.udf_table_nm)="&udf_table_nm"  
                 and a.&datatype._rk=b.&datatype._rk and a.valid_from_dttm=b.valid_from_dttm
        
     %end;
     %else
     %do;
     where   upcase(a.udf_table_nm)="&udf_table_nm"  and a.valid_to_dttm=. 
     %end;

      /* filter the data if datatype_rk or subset_dsn is non blank */
     %if &datatype_rk ne %then
     %do;
         and a.&datatype._rk in (&datatype_rk)
     %end;
     %else %if &subset_dsn ne %then
     %do;
            and a.&datatype._rk in (select distinct &datatype._rk from &subset_dsn)
     %end;
     ) 
   %end;         

; quit;


proc sort data=&out_dsn;
by &datatype._rk valid_from_dttm row_no udf_nm;
run;

%end;

%MEXIT:

   %put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;


%mend;
